aboutsummaryrefslogtreecommitdiffstats
path: root/src/tag/TagItem.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'src/tag/TagItem.hxx')
-rw-r--r--src/tag/TagItem.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tag/TagItem.hxx b/src/tag/TagItem.hxx
index 5db9a2116..7c3100393 100644
--- a/src/tag/TagItem.hxx
+++ b/src/tag/TagItem.hxx
@@ -24,13 +24,13 @@
#include "Compiler.h"
/**
* One tag value. It is a mapping of #tag_type to am arbitrary string
* value. Each tag can have multiple items of one tag type (although
* few clients support that).
*/
struct TagItem {
/** the type of this item */
- enum tag_type type;
+ TagType type;
/**
* the value of this tag; this is a variable length string
@@ -24,13 +24,13 @@
#include "Compiler.h"
/**
- * One tag value. It is a mapping of #tag_type to am arbitrary string
+ * One tag value. It is a mapping of #TagType to am arbitrary string
* value. Each tag can have multiple items of one tag type (although
* few clients support that).